@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2010 Index Data
+   Copyright (C) 2005-2012 Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -30,6 +30,9 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include "filter_auth_simple.hpp"
 #include "filter_backend_test.hpp"
 #include "filter_bounce.hpp"
+#ifndef WIN32
+#include "filter_cgi.hpp"
+#endif
 #include "filter_cql_to_rpn.hpp"
 #include "filter_frontend_net.hpp"
 #include "filter_http_file.hpp"
@@ -40,11 +43,13 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include "filter_query_rewrite.hpp"
 #include "filter_record_transform.hpp"
 #include "filter_session_shared.hpp"
+#include "filter_sort.hpp"
 #include "filter_sru_to_z3950.hpp"
 #include "filter_template.hpp"
 #include "filter_virt_db.hpp"
 #include "filter_z3950_client.hpp"
 #include "filter_zeerex_explain.hpp"
+#include "filter_zoom.hpp"
 
 namespace mp = metaproxy_1;
 
@@ -54,6 +59,9 @@ mp::FactoryStatic::FactoryStatic()
         &metaproxy_1_filter_auth_simple,
         &metaproxy_1_filter_backend_test,
         &metaproxy_1_filter_bounce,
+#ifndef WIN32
+        &metaproxy_1_filter_cgi,
+#endif
         &metaproxy_1_filter_cql_to_rpn,
         &metaproxy_1_filter_frontend_net,        
         &metaproxy_1_filter_http_file,
@@ -64,11 +72,13 @@ mp::FactoryStatic::FactoryStatic()
         &metaproxy_1_filter_query_rewrite,
         &metaproxy_1_filter_record_transform,
         &metaproxy_1_filter_session_shared,
+        &metaproxy_1_filter_sort,
         &metaproxy_1_filter_sru_to_z3950,
         &metaproxy_1_filter_template,
         &metaproxy_1_filter_virt_db,
         &metaproxy_1_filter_z3950_client,
         &metaproxy_1_filter_zeerex_explain,
+        &metaproxy_1_filter_zoom,
         0
     };
     int i;
