@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2010 Index Data
+   Copyright (C) 2005-2012 Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -32,6 +32,8 @@ namespace mp = metaproxy_1;
 class TFilter: public mp::filter::Base {
 public:
     void process(mp::Package & package) const {};
+    void configure(const xmlNode * ptr, bool test_only,
+                   const char *path) { };
 };
     
 
