@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2010 Index Data
+   Copyright (C) 2005-2012 Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -213,7 +213,7 @@ BOOST_AUTO_TEST_CASE( test_filter_query_rewrite3 )
 
         // creating and configuring filter
         mp::filter::QueryRewrite f_query_rewrite;
-        f_query_rewrite.configure(root_element, true);
+        f_query_rewrite.configure(root_element, true, 0);
         
         // remeber to free XML DOM
         xmlFreeDoc(doc);
