@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2010 Index Data
+   Copyright (C) 2005-2012 Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -39,7 +39,8 @@ class My_Timer_Thread;
 class My_Msg : public mp::IThreadPoolMsg {
 public:
     mp::IThreadPoolMsg *handle();
-    void result();
+    void result(const char *t_info);
+    bool cleanup(void *info);
     int m_val;
     My_Timer_Thread *m_timer;
 };
@@ -70,7 +71,12 @@ mp::IThreadPoolMsg *My_Msg::handle()
     return res;
 }
 
-void My_Msg::result()
+bool My_Msg::cleanup(void *info)
+{
+    return false;
+}
+
+void My_Msg::result(const char *t_info)
 {
     m_timer->m_sum += m_val;
     m_timer->m_responses++;
